@@ -25,7 +25,13 @@ def report(label, n = 10, &block)
   puts
 end
 
+# make rubygems load specifications now so the
+# time is not included below.
+Gem::Specification._all
+
 N = 10
 
 report("require fog:", N)             { require 'fog' }
 report("require fog/aws:", N)         { require 'fog/aws' }
+report("require fog/aws/compute:", N) { require 'fog/aws/compute' }
+report("require fog/aws/core:", N)    { require 'fog/aws/core'}
