@@ -2,7 +2,6 @@ require 'fog/core/credentials'
 
 module Fog
   class << self
-
     def available_providers
       @available_providers ||= Fog.providers.values.select {|provider| Kernel.const_get(provider).available?}.sort
     end
@@ -10,12 +9,10 @@ module Fog
     def registered_providers
       @registered_providers ||= Fog.providers.values.sort
     end
-
   end
 
   class Bin
     class << self
-
       def available?
         availability = true
         for service in services
@@ -50,10 +47,8 @@ module Fog
       def collections
         services.map {|service| self[service].collections}.flatten.sort_by {|service| service.to_s}
       end
-
     end
   end
-
 end
 
 require 'fog/bin/atmos'
@@ -76,7 +71,6 @@ require 'fog/bin/hp'
 require 'fog/bin/ibm'
 require 'fog/bin/internet_archive'
 require 'fog/bin/joyent'
-require 'fog/bin/libvirt'
 require 'fog/bin/linode'
 require 'fog/bin/local'
 require 'fog/bin/bare_metal_cloud'
@@ -86,9 +80,12 @@ require 'fog/bin/rage4'
 require 'fog/bin/riakcs'
 require 'fog/bin/openstack'
 require 'fog/bin/ovirt'
+require 'fog/bin/powerdns'
+require 'fog/bin/profitbricks'
 require 'fog/bin/sakuracloud'
 require 'fog/bin/serverlove'
-require 'fog/bin/stormondemand'
+require 'fog/bin/softlayer'
+require 'fog/bin/storm_on_demand'
 require 'fog/bin/terremark'
 require 'fog/bin/vcloud'
 require 'fog/bin/vcloud_director'
@@ -99,3 +96,4 @@ require 'fog/bin/xenserver'
 require 'fog/bin/zerigo'
 require 'fog/bin/cloudsigma'
 require 'fog/bin/openvz'
+require 'fog/bin/opennebula'
