@@ -2,7 +2,6 @@ module Fog
   module Compute
     class DigitalOcean
       class Real
-
         #
         # FIXME: missing ssh keys support
         #
@@ -25,6 +24,8 @@ module Fog
           end
 
           query_hash[:private_networking] = !!options[:private_networking]
+          # backups are enabled using backups_enabled query parameter!
+          query_hash[:backups_enabled] = !!options[:backups_active]
 
           request(
             :expects  => [200],
@@ -33,11 +34,9 @@ module Fog
             :query    => query_hash
           )
         end
-
       end
 
       class Mock
-
         def create_server( name,
                            size_id,
                            image_id,
@@ -46,6 +45,11 @@ module Fog
           response = Excon::Response.new
           response.status = 200
 
+          # New York 2 (region id 4) is currently the only region that supports
+          # private networking.  The Digital Ocean IP will return a null
+          # private_ip_address for any other region
+          has_private_ip = !!options[:private_networking] && (region_id == 4)
+
           mock_data = {
             "id" => Fog::Mock.random_numbers(1).to_i,
             "event_id" => Fog::Mock.random_numbers(2).to_i,
@@ -54,6 +58,7 @@ module Fog
             "image_id" => image_id,
             "region_id" => region_id,
             "ip_address" => "127.0.0.1",
+            "private_ip_address" => has_private_ip ? "10.0.0.1" : nil,
             "status" => 'active',
             "created_at" => Time.now.strftime("%FT%TZ")
           }
@@ -66,7 +71,6 @@ module Fog
           self.data[:servers] << mock_data
           response
         end
-
       end
     end
   end
