@@ -3,7 +3,7 @@ module Fog
     class Fogdocker
       class Real
         def image_all(filters = {})
-          Docker::Image.all.map do |image|
+          Docker::Image.all({}, @connection).map do |image|
             downcase_hash_keys(image.json)
           end
         end
