@@ -4,9 +4,7 @@ require 'fog/hp/models/network/router'
 module Fog
   module HP
     class Network
-
       class Routers < Fog::Collection
-
         attribute :filters
 
         model Fog::HP::Network::Router
@@ -16,8 +14,8 @@ module Fog
           super
         end
 
-        def all(filters = filters)
-          self.filters = filters
+        def all(filters_arg = filters)
+          filters = filters_arg
           non_aliased_filters = Fog::HP.convert_aliased_attributes_to_original(self.model, filters)
           load(service.list_routers(non_aliased_filters).body['routers'])
         end
@@ -29,7 +27,6 @@ module Fog
         rescue Fog::HP::Network::NotFound
           nil
         end
-
       end
     end
   end
