@@ -2,7 +2,6 @@ module Fog
   module Compute
     class HP
       class Real
-
         # Delete an existing server
         #
         # ==== Parameters
@@ -15,14 +14,12 @@ module Fog
             :path   => "servers/#{server_id}"
           )
         end
-
       end
 
       class Mock
-
         def delete_server(server_id)
           response = Excon::Response.new
-          if server = list_servers_detail.body['servers'].detect {|_| _['id'] == server_id}
+          if server = list_servers_detail.body['servers'].find {|_| _['id'] == server_id}
             if server['status'] == 'BUILD'
               response.status = 409
               raise(Excon::Errors.status_error({:expects => 202}, response))
@@ -36,7 +33,6 @@ module Fog
             raise Fog::Compute::HP::NotFound
           end
         end
-
       end
     end
   end
