@@ -2,7 +2,6 @@ module Fog
   module Compute
     class HP
       class Real
-
         # Get details for image by id
         #
         # ==== Returns
@@ -20,14 +19,12 @@ module Fog
             :path     => "images/#{image_id}.json"
           )
         end
-
       end
 
       class Mock
-
         def get_image_details(image_id)
           response = Excon::Response.new
-          if image = list_images_detail.body['images'].detect {|_| _['id'] == image_id}
+          if image = list_images_detail.body['images'].find {|_| _['id'] == image_id}
             response.status = [200, 203][rand(1)]
             response.body = { 'image' => image }
             response
@@ -35,9 +32,7 @@ module Fog
             raise Fog::Compute::HP::NotFound
           end
         end
-
       end
-
     end
   end
 end
