@@ -2,7 +2,6 @@ module Fog
   module Compute
     class HP
       class Real
-
         # Reboot an existing server
         #
         # ==== Parameters
@@ -13,21 +12,18 @@ module Fog
           body = { 'reboot' => { 'type' => type }}
           server_action(server_id, body)
         end
-
       end
 
       class Mock
-
         def reboot_server(server_id, type = 'SOFT')
           response = Excon::Response.new
-          if list_servers_detail.body['servers'].detect {|_| _['id'] == server_id}
+          if list_servers_detail.body['servers'].find {|_| _['id'] == server_id}
             response.status = 202
             response
           else
             raise Fog::Compute::HP::NotFound
           end
         end
-
       end
     end
   end
