@@ -2,7 +2,6 @@ module Fog
   module Compute
     class HPV2
       class Real
-
         # Delete an image
         #
         # ==== Parameters
@@ -15,14 +14,12 @@ module Fog
             :path     => "images/#{image_id}"
           )
         end
-
       end
 
       class Mock
-
         def delete_image(image_id)
           response = Excon::Response.new
-          if image = list_images_detail.body['images'].detect {|_| _['id'] == image_id}
+          if image = list_images_detail.body['images'].find {|_| _['id'] == image_id}
             if image['status'] == 'SAVING'
               response.status = 409
               raise(Excon::Errors.status_error({:expects => 202}, response))
@@ -35,9 +32,7 @@ module Fog
           else
             raise Fog::Compute::HPV2::NotFound
           end
-
         end
-
       end
     end
   end
