@@ -2,7 +2,6 @@ module Fog
   module Compute
     class HPV2
       class Real
-
         # Retrieve VNC console for the specified instance
         #
         # ==== Parameters
@@ -19,18 +18,16 @@ module Fog
           body = { 'os-getVNCConsole' => { 'type' => type }}
           server_action(server_id, body, 200)
         end
-
       end
 
       class Mock
-
         def get_vnc_console(server_id, type='novnc')
           output = {
               'type' => type,
               'url'  => 'https://region.compute.hpcloud.com/vnc_auto.html?token=123ABX234'
           }
           response = Excon::Response.new
-          if list_servers_detail.body['servers'].detect {|_| _['id'] == server_id}
+          if list_servers_detail.body['servers'].find {|_| _['id'] == server_id}
             response.body = { 'console' => output }
             response.status = 200
           else
@@ -38,7 +35,6 @@ module Fog
           end
           response
         end
-
       end
     end
   end
