@@ -1,7 +1,6 @@
 module Fog
   module HP
     class DNS
-
       class Real
         # Update an existing DNS record
         #
@@ -43,13 +42,12 @@ module Fog
             :path    => "domains/#{domain_id}/records/#{record_id}"
           )
         end
-
       end
 
       class Mock
         def update_record(domain_id, record_id, options)
           response = Excon::Response.new
-          if record = list_records_in_a_domain(domain_id).body['records'].detect { |_| _['id'] == record_id }
+          if record = list_records_in_a_domain(domain_id).body['records'].find { |_| _['id'] == record_id }
             record['name']      = options[:name]      if options[:name]
             record['type']      = options[:type]      if options[:type]
             record['data']      = options[:data]      if options[:data]
@@ -62,9 +60,7 @@ module Fog
             raise Fog::HP::DNS::NotFound
           end
         end
-
       end
-
     end
   end
 end
