@@ -1,7 +1,6 @@
 module Fog
   module HP
     class LB
-
       # Update an existing load balancer
       #
       # ==== Parameters
@@ -24,12 +23,11 @@ module Fog
             :path    => "loadbalancers/#{load_balancer_id}"
           )
         end
-
       end
       class Mock
         def update_load_balancer(load_balancer_id, options={})
           response = Excon::Response.new
-          if lb = list_load_balancers.body['loadBalancers'].detect { |_| _['id'] == load_balancer_id }
+          if lb = list_load_balancers.body['loadBalancers'].find { |_| _['id'] == load_balancer_id }
 
             lb['name']      = options['name']      if options['name']
             lb['algorithm'] = options['algorithm'] if options['algorithm']
