@@ -1,7 +1,6 @@
 module Fog
   module HP
     class Network
-
       class Real
         # Delete an existing subnet
         #
@@ -19,7 +18,7 @@ module Fog
       class Mock
         def delete_subnet(subnet_id)
           response = Excon::Response.new
-          if list_subnets.body['subnets'].detect {|_| _['id'] == subnet_id}
+          if list_subnets.body['subnets'].find {|_| _['id'] == subnet_id}
             self.data[:subnets].delete(subnet_id)
             response.status = 204
             response
@@ -28,7 +27,6 @@ module Fog
           end
         end
       end
-
     end
   end
 end
