@@ -1,7 +1,6 @@
 module Fog
   module HP
     class Network
-
       class Real
         # Get details for an existing port by id
         #
@@ -38,7 +37,7 @@ module Fog
       class Mock
         def get_port(port_id)
           response = Excon::Response.new
-          if port = list_ports.body['ports'].detect {|_| _['id'] == port_id}
+          if port = list_ports.body['ports'].find {|_| _['id'] == port_id}
             response.status = 200
             response.body = { 'port' => port }
             response
@@ -47,7 +46,6 @@ module Fog
           end
         end
       end
-
     end
   end
 end
