@@ -1,7 +1,6 @@
 module Fog
   module HP
     class Network
-
       class Real
         # Remove an internal router interface, thus detaching a subnet or a port from an existing router
         #
@@ -38,7 +37,7 @@ module Fog
       class Mock
         def remove_router_interface(router_id, subnet_id=nil, port_id=nil, options = {})
           response = Excon::Response.new
-          if list_routers.body['routers'].detect {|_| _['id'] == router_id}
+          if list_routers.body['routers'].find {|_| _['id'] == router_id}
             # Either a subnet or a port can be passed, not both
             if (subnet_id && port_id) || (subnet_id.nil? && port_id.nil?)
               raise ArgumentError.new('Either a subnet or a port can be passed, not both')
@@ -61,7 +60,6 @@ module Fog
           end
         end
       end
-
     end
   end
 end
