@@ -27,9 +27,9 @@ module Fog
 
         private
         def ips(linode_id, id=nil)
-          connection.linode_ip_list(linode_id, id).body['DATA'].map { |ip| map_ip ip }
+          service.linode_ip_list(linode_id, id).body['DATA'].map { |ip| map_ip ip }
         end
-        
+
         def map_ip(ip)
           ip = ip.each_with_object({}) { |(k, v), h| h[k.downcase.to_sym] = v  }
           ip.merge! :id => ip[:ipaddressid], :ip => ip[:ipaddress], :public => ip[:ispublic]==1
