@@ -12,7 +12,7 @@ module Fog
       requires :ninefold_storage_token, :ninefold_storage_secret
       recognizes :persistent
 
-      model_path 'fog/atmos/models/storage'
+      model_path 'fog/storage/atmos/models'
       model       :directory
       collection  :directories
       model       :file
@@ -32,7 +32,6 @@ module Fog
         def request(options)
           raise "Ninefold Storage mocks not implemented"
         end
-
       end
 
       class Real < Fog::Storage::Atmos::Real
