@@ -52,6 +52,10 @@ module Fog
         attr_writer :image_ref, :flavor_ref, :nics, :os_scheduler_hints
         attr_accessor :block_device_mapping, :block_device_mapping_v2
 
+        # In some cases it's handy to be able to store the project for the record, e.g. swift doesn't contain project info
+        # in the result, so we can track it in this attribute based on what project was used in the request
+        attr_accessor :project
+
         def initialize(attributes={})
           # Old 'connection' is renamed as service and should be used instead
           prepare_service_value(attributes)
@@ -84,7 +88,7 @@ module Fog
         end
 
         def user_data=(ascii_userdata)
-          self.user_data_encoded = [ascii_userdata].pack('m')
+          self.user_data_encoded = [ascii_userdata].pack('m') if ascii_userdata
         end
 
         def destroy
@@ -208,7 +212,7 @@ module Fog
         def security_groups
           requires :id
 
-          groups = service.list_security_groups(id).body['security_groups']
+          groups = service.list_security_groups(:server_id => id).body['security_groups']
 
           groups.map do |group|
             Fog::Compute::OpenStack::SecurityGroup.new group.merge({:service => service})
@@ -253,6 +257,21 @@ module Fog
           end
         end
 
+        def shelve
+          requires :id
+          service.shelve_server(id)
+        end
+
+        def unshelve
+          requires :id
+          service.unshelve_server(id)
+        end
+
+        def shelve_offload
+          requires :id
+          service.shelve_offload_server(id)
+        end
+
         def create_image(name, metadata={})
           requires :id
           service.create_image(id, name, metadata)
