@@ -1,10 +1,10 @@
-require 'fog/core/collection'
+require 'fog/openstack/models/collection'
 require 'fog/openstack/models/network/lb_pool'
 
 module Fog
   module Network
     class OpenStack
-      class LbPools < Fog::Collection
+      class LbPools < Fog::OpenStack::Collection
         attribute :filters
 
         model Fog::Network::OpenStack::LbPool
@@ -16,7 +16,7 @@ module Fog
 
         def all(filters_arg = filters)
           filters = filters_arg
-          load(service.list_lb_pools(filters).body['pools'])
+          load_response(service.list_lb_pools(filters), 'pools')
         end
 
         def get(pool_id)
