@@ -1,9 +1,9 @@
-require 'fog/core/collection'
+require 'fog/openstack/models/collection'
 
 module Fog
   module Orchestration
     class OpenStack
-      class ResourceSchemas < Fog::Collection
+      class ResourceSchemas < Fog::OpenStack::Collection
 
         def get(resource_type)
           service.show_resource_schema(resource_type).body
