@@ -1,15 +1,15 @@
-require 'fog/core/collection'
+require 'fog/openstack/models/collection'
 require 'fog/openstack/models/volume/volume_type'
 
 module Fog
   module Volume
     class OpenStack
-      class VolumeTypes < Fog::Collection
+      class VolumeTypes < Fog::OpenStack::Collection
         model Fog::Volume::OpenStack::VolumeType
 
         def all(options = {})
           response = service.list_volume_types(options)
-          load(response.body['volume_types'])
+          load_response(response, 'volume_types')
         end
 
         def get(volume_type_id)
@@ -19,7 +19,6 @@ module Fog
         rescue Fog::Volume::OpenStack::NotFound
           nil
         end
-        alias_method :find_by_id, :get
       end
     end
   end
