@@ -2,20 +2,18 @@ module Fog
   module Compute
     class OpenStack
       class Real
-
-        def list_hosts
+        def list_hosts(options = {})
           request(
             :expects  => [200, 203],
             :method   => 'GET',
-            :path     => 'os-hosts.json'
+            :path     => 'os-hosts.json',
+            :query    => options
           )
         end
-
       end
 
       class Mock
-
-        def list_hosts
+        def list_hosts(options = {})
           response = Excon::Response.new
           response.status = 200
           response.body = { "hosts" => [
@@ -24,8 +22,6 @@ module Fog
           }
           response
         end
-
-
       end # mock
     end # openstack
   end # compute
