@@ -12,7 +12,7 @@ module Fog
           }
 
           vanilla_options = [:snapshot_id, :imageRef, :volume_type,
-            :source_volid, :availability_zone]
+            :source_volid, :availability_zone, :metadata]
           vanilla_options.select{|o| options[o]}.each do |key|
             data['volume'][key] = options[key]
           end
@@ -34,6 +34,7 @@ module Fog
               'id'                  => Fog::Mock.random_numbers(2),
               'display_name'        => name,
               'display_description' => description,
+              'metadata'            => options['metadata'] || {},
               'size'                => size,
               'status'              => 'creating',
               'snapshot_id'         => options[:snapshot_id] || nil,
