@@ -2,20 +2,17 @@ module Fog
   module Compute
     class Ovirt
       class Real
-
         def destroy_vm(options = {})
-          raise ArgumentError, "instance id is a required parameter" unless options.has_key? :id
+          raise ArgumentError, "instance id is a required parameter" unless options.key? :id
           client.destroy_vm(options[:id])
         end
-
       end
 
       class Mock
         def destroy_vm(options = {})
-          raise ArgumentError, "instance id is a required parameter" unless options.has_key? :id
+          raise ArgumentError, "instance id is a required parameter" unless options.key? :id
           true
         end
-
       end
     end
   end
