@@ -5,12 +5,11 @@ module Fog
         def list_vm_volumes(vm_id)
           client.vm_volumes(vm_id).map {|ovirt_obj| ovirt_attrs ovirt_obj}
         end
-
       end
       class Mock
         def list_vm_volumes(vm_id)
           xml = read_xml 'volumes.xml'
-          Nokogiri::XML(xml).xpath('/disks/disk').collect do |vol|
+          Nokogiri::XML(xml).xpath('/disks/disk').map do |vol|
             ovirt_attrs OVIRT::Volume::new(self, vol)
           end
         end
