@@ -10,7 +10,6 @@ module Fog
       class BadRequest < Fog::Rackspace::Errors::BadRequest; end
 
       class InvalidStateException < ::RuntimeError
-
         attr_reader :desired_state
         attr_reader :current_state
 
@@ -136,7 +135,7 @@ module Fog
           headers = params[:headers] || {}
 
           response = Excon::Response.new(:body => body, :headers => headers, :status => status)
-          if params.has_key?(:expects) && ![*params[:expects]].include?(response.status)
+          if params.key?(:expects) && ![*params[:expects]].include?(response.status)
             raise(Excon::Errors.status_error(params, response))
           else response
           end
@@ -144,7 +143,6 @@ module Fog
       end
 
       class Real < Fog::Rackspace::Service
-
         def initialize(options = {})
           @rackspace_api_key = options[:rackspace_api_key]
           @rackspace_username = options[:rackspace_username]
@@ -216,7 +214,7 @@ module Fog
               @rackspace_region = :lon
             else
               # we are actually using a custom endpoint
-              @rackspace_region = options[:rackspace_region] || :dfw
+              @rackspace_region = options[:rackspace_region]
             end
           else
             #if we are using auth1 and the endpoint is not set, default to DFW_ENDPOINT for historical reasons
@@ -231,10 +229,6 @@ module Fog
             regions = @identity_service.service_catalog.display_service_regions(service_name)
             Fog::Logger.deprecation("Please specify region using :rackspace_region rather than :rackspace_endpoint. Valid regions for :rackspace_region are #{regions}.")
           end
-
-          unless options[:rackspace_region]
-            Fog::Logger.deprecation("Default region support will be removed in an upcoming release. Please switch to manually setting your endpoint. This requires setting the :rackspace_region option")
-          end
         end
 
         def append_tenant_v1(credentials)
