@@ -2,7 +2,6 @@ module Fog
   module Compute
     class Rackspace
       class Real
-
         # List private server addresses
         #
         # ==== Parameters
@@ -19,14 +18,12 @@ module Fog
             :path     => "servers/#{server_id}/ips/private.json"
           )
         end
-
       end
 
       class Mock
-
         def list_private_addresses(server_id)
           response = Excon::Response.new
-          if server = list_servers_detail.body['servers'].detect {|_| _['id'] == server_id}
+          if server = list_servers_detail.body['servers'].find {|_| _['id'] == server_id}
             response.status = [200, 203][rand(1)]
             response.body = { 'private' => server['addresses']['private'] }
             response
@@ -34,7 +31,6 @@ module Fog
             raise Fog::Compute::Rackspace::NotFound
           end
         end
-
       end
     end
   end
