@@ -2,7 +2,6 @@ module Fog
   module Compute
     class Rackspace
       class Real
-
         # Update an existing server
         #
         # ==== Parameters
@@ -18,14 +17,12 @@ module Fog
             :path     => "servers/#{server_id}.json"
           )
         end
-
       end
 
       class Mock
-
         def update_server(server_id, options)
           response = Excon::Response.new
-          if server = list_servers_detail.body['servers'].detect {|_| _['id'] == server_id}
+          if server = list_servers_detail.body['servers'].find {|_| _['id'] == server_id}
             if options['adminPass']
               server['adminPass'] = options['adminPass']
             end
@@ -38,7 +35,6 @@ module Fog
             raise Fog::Compute::Rackspace::NotFound
           end
         end
-
       end
     end
   end
