@@ -3,11 +3,10 @@ module Fog
     class Rackspace
       class Real
         def remove_domains(domain_ids, options={})
-
-          path = "domains?" + domain_ids.collect { |domain_id| "id=#{domain_id}" }.join('&')
+          path = "domains?" + domain_ids.map { |domain_id| "id=#{domain_id}" }.join('&')
           query_data = {}
 
-          if options.has_key? :delete_subdomains
+          if options.key? :delete_subdomains
             query_data['deleteSubdomains'] = options[:delete_subdomains]
           end
 
