@@ -3,10 +3,9 @@ module Fog
     class Rackspace
       class Real
         def remove_records(domain_id, record_ids)
-
           validate_path_fragment :domain_id, domain_id
 
-          path = "domains/#{domain_id}/records?" + record_ids.collect { |record_id| "id=#{record_id}" }.join('&')
+          path = "domains/#{domain_id}/records?" + record_ids.map { |record_id| "id=#{record_id}" }.join('&')
 
           request(
             :expects  => [202, 204],
