@@ -11,9 +11,12 @@ module Fog
                 'condition' => condition
               }
           ]}
-          if options.has_key?(:weight)
+          if options.key?(:weight)
             data['nodes'][0]['weight'] = options[:weight]
           end
+          if options.key? :type
+            data['node']['type'] = options[:type]
+          end
           request(
             :body     => Fog::JSON.encode(data),
             :expects  => [200, 202],
