@@ -4,7 +4,7 @@ module Fog
       class Real
         def get_load_balancer_usage(load_balancer_id, options = {})
           #TODO - Didn't implement usage/current.  Not sure if it is needed
-          if options.has_key? :start_time and options.has_key? :end_time
+          if options.key? :start_time and options.key? :end_time
             query = "?startTime=#{options[:start_time]}&endTime=#{options[:end_time]}"
           else
             query = ''
