@@ -9,7 +9,7 @@ module Fog
             }
           }
           request(
-            :body     => MultiJson.encode(data),
+            :body     => Fog::JSON.encode(data),
             :expects  => [200, 202],
             :path     => "loadbalancers/#{load_balancer_id}/sessionpersistence",
             :method   => 'PUT'
