@@ -4,12 +4,18 @@ require 'fog/vcloud_director/models/compute/task'
 module Fog
   module Compute
     class VcloudDirector
-
       class Tasks < Collection
+
+        include Fog::VcloudDirector::Query
+
         model Fog::Compute::VcloudDirector::Task
 
         attribute :organization
 
+        def query_type
+          "task"
+        end
+
         def get(id)
           data = service.get_task(id).body
           return nil unless data
@@ -24,7 +30,6 @@ module Fog
           data = service.get_task_list(organization.id).body
           data[:Task].each {|task| service.add_id_from_href!(task)}
         end
-
       end
     end
   end
