@@ -103,7 +103,7 @@ module Fog
             #    "#{response.body[:name]}Record".to_sym
 
             %w[firstPage previousPage nextPage lastPage].each do |rel|
-              if link = response.body[:Link].detect {|l| l[:rel] == rel}
+              if link = response.body[:Link].find {|l| l[:rel] == rel}
                 href = Nokogiri::XML.fragment(link[:href])
                 query = CGI.parse(URI.parse(href.text).query)
                 response.body[rel.to_sym] = query['page'].first.to_i
@@ -118,7 +118,6 @@ module Fog
 
       class Mock
         def get_execute_query(type=nil, options={})
-
           unless options[:fields].nil?
             Fog::Mock.not_implemented("Fields are not yet implemented in get_execute_query Mock for #{type}")
           end
@@ -158,15 +157,17 @@ module Fog
             :headers => {'Content-Type' => "#{body[:type]};version=#{api_version}"},
             :body    => body
           )
-
         end
 
         private
 
         def fetch_items(type, opts)
-
           if opts.key?(:filter) && opts[:filter] =~ /^name==([^;,]+)$/
             name = $1
+          elsif type == 'vAppTemplate' && opts.key?(:filter) &&
+            opts[:filter] =~ /^name==([^;,]+);catalogName==([^;,]+)$/ #TODO also match in other order
+            name = $1
+            catalog_name = $2
           elsif opts.key?(:filter)
             Fog::Mock.not_implemented("Complex filters are not yet implemented in get_execute_query Mock for #{type}: #{opts[:filter]}")
           end
@@ -180,10 +181,36 @@ module Fog
             :xsi_schemaLocation=>xsi_schema_location,
           }
 
-          if type == 'orgVdcNetwork'
+          records = []
+          record_type = nil
+
+          if type == 'orgVdc'
+            record_type = :OrgVdcRecord
+            vdc_id = data[:vdcs].keys[0]
+            vdc_name = data[:vdcs][vdc_id][:name]
+            records = [{
+              :storageUsedMB=>"123967",
+              :storageLimitMB=>"8388608",
+              :storageAllocationMB=>"0",
+              :status=>"READY",
+              :orgName=>"orgName",
+              :name=>vdc_name,
+              :memoryUsedMB=>"0",
+              :memoryLimitMB=>"0",
+              :memoryAllocationMB=>"0",
+              :isSystemVdc=>"false",
+              :isEnabled=>"true",
+              :isBusy=>"false",
+              :href=>make_href("vdc/#{vdc_id}"),
+            }]
+            body[:page]     = 1.to_s             # TODO: Support pagination
+            body[:pageSize] = records.size.to_s  # TODO: Support pagination
+            body[:total]    = records.size.to_s
+            body[record_type] = records
+
+          elsif type == 'orgVdcNetwork'
             record_type = :OrgVdcNetworkRecords
             data_type = :networks
-            records = []
             data[data_type].each do |id, dr|
               r = {}
               if name.nil? || dr[:name] == name
@@ -218,10 +245,154 @@ module Fog
             body[:pageSize] = records.size.to_s  # TODO: Support pagination
             body[:total]    = records.size.to_s
             body[record_type] = records
+
+          elsif type == 'edgeGateway'
+            record_type = :EdgeGatewayRecord
+            edge_gateway_id = data[:edge_gateways].keys[0]
+            vdc_id = data[:edge_gateways][edge_gateway_id][:vdc]
+            records = [{
+              :vdc=>make_href("vdc/#{vdc_id}"),
+              :numberOfOrgNetworks=>"1",
+              :numberOfExtNetworks=>"1",
+              :name=>"Test EdgeGateway Name",
+              :isBusy=>"false",
+              :haStatus=>"DISABLED",
+              :gatewayStatus=>"READY",
+              :href=>make_href("edgeGateway/#{edge_gateway_id}"),
+              :taskStatus=>"success",
+              :taskOperation=>"networkConfigureEdgeGatewayServices",
+              :task=>make_href("task/#{uuid}"),
+              :taskDetails=>" "
+            }]
+            body[:page]     = 1.to_s             # TODO: Support pagination
+            body[:pageSize] = records.size.to_s  # TODO: Support pagination
+            body[:total]    = records.size.to_s
+            body[record_type] = records
+
+          elsif type == 'vAppTemplate'
+            record_type = :VAappTemplateRecord
+            records = [{
+              :vdcName=>"Bogus vDC",
+              :vdc=>make_href("vdc/#{uuid}"),
+              :storageProfileName=>"*",
+              :status=>"RESOLVED",
+              :ownerName=>"system",
+              :org=> make_href("org/#{data[:org][:uuid]}"),
+              :name=> name,
+              :isPublished=>"true",
+              :isGoldMaster=>"false",
+              :isExpired=>"false",
+              :isEnabled=>"true",
+              :isDeployed=>"false",
+              :isBusy=>"false",
+              :creationDate=>"2013-09-19T22:55:30.257+01:00",
+              :catalogName=> catalog_name,
+              :href=> make_href("vAppTemplate/vappTemplate-#{uuid}"),
+              :honorBootOrder=>"false",
+              :isVdcEnabled=>"true",
+              :isInCatalog=>"true",
+              :cpuAllocationMhz=>"8",
+              :cpuAllocationInMhz=>"16000",
+              :storageKB=>"52428800",
+              :numberOfShadowVMs=>"0",
+              :numberOfVMs=>"1",
+              :isAutoDeleteNotified=>"false",
+              :numberOfCpus=>"8",
+              :isAutoUndeployNotified=>"false",
+              :memoryAllocationMB=>"32768"
+            }]
+            body[:page]     = 1.to_s             # TODO: Support pagination
+            body[:pageSize] = records.size.to_s  # TODO: Support pagination
+            body[:total]    = records.size.to_s
+            body[record_type] = records
+
+          elsif type == 'vApp'
+            record_type = :VAppRecord
+            all_records = data[:vapps].map do |vapp_id, vapp|
+              {
+                :vdcName => data.fetch(:vdcs).fetch(vapp[:vdc_id]).fetch(:name),
+                :vdc => make_href("vdc/#{vapp[:vdc_id]}"),
+                :storageProfileName => "*",
+                :ownerName => "system",
+                :name => vapp.fetch(:name),
+                :status => 'POWERED_OFF',
+                :isInMaintenanceMode=> 'false',
+                :isPublic => 'false',
+                :isExpired =>"false",
+                :isEnabled =>"true",
+                :isDeployed =>"false",
+                :isBusy => "false",
+                :pvdcHighestSupportedHardwareVersion => '8',
+                :lowestHardwareVersionInVApp => '8',
+                :creationDate => "2013-09-19T22:55:30.257+01:00",
+                :href => make_href("vApp/#{vapp_id}"),
+                :honorBootOrder => "false",
+                :isVdcEnabled => "true",
+                :cpuAllocationMhz => "8",
+                :cpuAllocationInMhz => "16000",
+                :storageKB => "52428800",
+                :numberOfVMs => "1",
+                :isAutoDeleteNotified => "false",
+                :numberOfCpus => "8",
+                :isAutoUndeployNotified => "false",
+                :memoryAllocationMB => "32768",
+                :task => make_href("task/#{uuid}"),
+                :taskStatusName => 'vdcInstantiateVapp',
+                :taskStatus => 'success',
+                :taskDetails => " ",
+              }
+            end
+            records = all_records.select do |record|
+              record[:name] == name
+            end
+
+            body[:page]     = 1.to_s             # TODO: Support pagination
+            body[:pageSize] = records.size.to_s  # TODO: Support pagination
+            body[:total]    = records.size.to_s
+            body[record_type] = records
+
+          elsif type == 'task'
+
+            record_type = :TaskRecord
+            data_type = :tasks
+            data[data_type].each do |id, dr|
+              r = {}
+              if name.nil? || dr.fetch(:operation_name) == name
+                r[:name] = dr.fetch(:operation_name)
+                r[:href] = make_href("task/#{id}")
+                if dr.key?(:end_time)
+                  r[:endDate] = dr.fetch(:end_time).strftime('%Y-%m-%dT%H:%M:%S%z')
+                else
+                  r[:endDate] = nil
+                end
+                if dr.key?(:start_time)
+                  r[:startDate] = dr.fetch(:start_time).strftime('%Y-%m-%dT%H:%M:%S%z')
+                else
+                  r[:startDate] = nil
+                end
+                r[:status] = dr.fetch(:status)
+                r[:serviceNamespace] = 'com.vmware.vcloud'
+                r[:ownerName] = '000.0.000000'
+                r[:orgName] = data.fetch(:org).fetch(:name)
+                r[:org] = make_href("org/#{data[:org][:uuid]}")
+                r[:objectType] = dr.fetch(:owner).fetch(:type).split(/\./).last.split(/\+/).first
+                r[:objectName] = dr.fetch(:owner).fetch(:name, '') # objectName is optional
+                r[:object] = dr.fetch(:owner).fetch(:href)
+                r[:details] = '! []'
+
+                records << r
+              end
+            end
+
           else
             Fog::Mock.not_implemented("No 'get by name' get_execute_query Mock for #{type} (#{name})")
           end
 
+          body[:page]     = 1.to_s             # TODO: Support pagination
+          body[:pageSize] = records.size.to_s  # TODO: Support pagination
+          body[:total]    = records.size.to_s
+          body[record_type] = records
+
           body
         end
 
