@@ -11,7 +11,7 @@ module Fog
             new_folder = parent_folder.CreateFolder(:name => name)
             # output is cleaned up to return the new path
             # new path will be path/name, example: "Production/Pool1"
-            new_folder.path.reject { |a| a.first.class == "Folder" }.collect { |a| a.first.name }.join("/").sub(/^\/?Datacenters\/#{datacenter}\/vm\/?/, '')
+            new_folder.path.reject { |a| a.first.class == "Folder" }.map { |a| a.first.name }.join("/").sub(/^\/?Datacenters\/#{datacenter}\/vm\/?/, '')
           rescue => e
             raise e, "failed to create folder: #{e}"
           end
