@@ -2,12 +2,11 @@ module Fog
   module Compute
     class Vsphere
       class Real
-
         def add_vm_interface(vmid, options = {})
           raise ArgumentError, "instance id is a required parameter" unless vmid
 
           interface = get_interface_from_options(vmid, options.merge(:server_id => vmid))
-          vm_reconfig_hardware('instance_uuid' => vmid, 'hardware_spec' => {'deviceChange'=>[create_interface(interface)]})
+          vm_reconfig_hardware('instance_uuid' => vmid, 'hardware_spec' => {'deviceChange'=>[create_interface(interface, 0, :add, options)]})
         end
 
         def destroy_vm_interface(vmid, options = {})
@@ -40,7 +39,6 @@ module Fog
             raise ArgumentError, "interface is a required parameter or pass options with type and network"
           end
         end
-
       end
 
       class Mock
