@@ -3,7 +3,6 @@ require 'fog/xenserver/core'
 module Fog
   module Compute
     class XenServer < Fog::Service
-
       require 'fog/xenserver/utilities'
       require 'fog/xenserver/parser'
 
@@ -12,6 +11,7 @@ module Fog
       requires :xenserver_url
       recognizes :xenserver_defaults
       recognizes :xenserver_timeout
+      recognizes :xenserver_redirect_to_master
 
       model_path 'fog/xenserver/models/compute'
       model :blob
@@ -85,6 +85,7 @@ module Fog
       request :destroy_vif
       request :clone_server
       request :destroy_server
+      request :destroy_record
       request :unplug_vbd
       request :eject_vbd
       request :insert_vbd
@@ -115,14 +116,28 @@ module Fog
 
       class Real
 
+        attr_reader :connection
+
         def initialize(options={})
-          @host        = options[:xenserver_url]
-          @username    = options[:xenserver_username]
-          @password    = options[:xenserver_password]
-          @defaults    = options[:xenserver_defaults] || {}
-          @timeout     = options[:xenserver_timeout] || 30
-          @connection  = Fog::XenServer::Connection.new(@host, @timeout)
-          @connection.authenticate(@username, @password)
+          @host                 = options[:xenserver_url]
+          @username             = options[:xenserver_username]
+          @password             = options[:xenserver_password]
+          @defaults             = options[:xenserver_defaults] || {}
+          @timeout              = options[:xenserver_timeout] || 30
+          @redirect_to_master   = options[:xenserver_redirect_to_master] || false
+          @connection           = Fog::XenServer::Connection.new(@host, @timeout)
+          begin
+            @connection.authenticate(@username, @password)
+          rescue Fog::XenServer::HostIsSlave => e
+            if @redirect_to_master
+              Fog::Logger.debug "Redirecting to master #{e.master_ip}"
+              @host = e.master_ip
+              @connection  = Fog::XenServer::Connection.new(@host, @timeout)
+              @connection.authenticate(@username, @password)
+            else
+              raise e
+            end
+          end
         end
 
         def reload
@@ -143,11 +158,9 @@ module Fog
         def default_network
           networks.find { |n| n.name == (@defaults[:network] || "Pool-wide network associated with eth0") }
         end
-
       end
 
       class Mock
-
         def self.data
           @data ||= Hash.new do |hash, key|
             hash[key] = {}
@@ -167,10 +180,7 @@ module Fog
           @connection  = Fog::XML::Connection.new(@host)
           @connection.authenticate(@username, @password)
         end
-
       end
     end
   end
 end
-
-
