@@ -3,7 +3,6 @@ require 'fog/core/model'
 module Fog
   module Compute
     class XenServer
-
       class Host < Fog::Model
         # API Reference here:
         # http://docs.vmd.citrix.com/XenServer/6.2.0/1.0/en_gb/api/?c=host
@@ -60,15 +59,15 @@ module Fog
         attribute :software_version
 
         def pifs
-          __pifs.collect { |pif| service.pifs.get pif }
+          __pifs.map { |pif| service.pifs.get pif }
         end
 
         def pbds
-          __pbds.collect { |pbd| service.pbds.get pbd }
+          __pbds.map { |pbd| service.pbds.get pbd }
         end
 
         def resident_servers
-          __resident_vms.collect { |ref| service.servers.get ref }
+          __resident_vms.map { |ref| service.servers.get ref }
         end
 
         def resident_vms
@@ -151,9 +150,7 @@ module Fog
           # then reload manually
           #reload
         end
-
       end
-
     end
   end
 end
