@@ -3,7 +3,6 @@ require 'fog/core/model'
 module Fog
   module Compute
     class XenServer
-
       class StorageRepository < Fog::Model
         # API Reference here:
         # http://docs.vmd.citrix.com/XenServer/6.2.0/1.0/en_gb/api/?c=SR
@@ -31,11 +30,11 @@ module Fog
         attribute :virtual_allocation
 
         def vdis
-          __vdis.collect { |vdi| service.vdis.get vdi }
+          __vdis.map { |vdi| service.vdis.get vdi }
         end
 
         def pbds
-          __pbds.collect { |pbd| service.pbds.get pbd }
+          __pbds.map { |pbd| service.pbds.get pbd }
         end
 
         def scan
@@ -85,9 +84,7 @@ module Fog
           # then reload manually
           #reload
         end
-
       end
-
     end
   end
 end
