@@ -20,11 +20,10 @@ Shindo.tests("Fog::Compute[:digitalocean] | region model", ['digitalocean', 'com
       end
       tests("The attributes hash should have key") do
         attributes.each do |attribute|
-          test("#{attribute}") { model_attribute_hash.has_key? attribute }
+          test("#{attribute}") { model_attribute_hash.key? attribute }
         end
       end
     end
   end
 
 end
-
