@@ -21,7 +21,7 @@ Shindo.tests('Fog::Compute[:fogdocker] | image model', ['fogdocker']) do
       end
       tests("The attributes hash should have key") do
         (attributes-[:repo_tags]).each do |attribute|
-          test("#{attribute}") { model_attribute_hash.has_key? attribute }
+          test("#{attribute}") { model_attribute_hash.key? attribute }
         end
       end
     end
