@@ -6,11 +6,13 @@ Shindo.tests('Fog::Rackspace::LoadBalancers | usage', ['rackspace']) do
     tests('success') do
 
       tests("#get_usage()").formats(USAGE_FORMAT) do
-        @service.get_usage.body
+        pending
+        # @service.get_usage.body
       end
 
       tests("#get_usage(:start_time => '2010-05-10', :end_time => '2010-05-11')").formats(USAGE_FORMAT) do
-        @service.get_usage(:start_time => '2010-05-10', :end_time => '2010-05-11').body
+        pending
+        # @service.get_usage(:start_time => '2010-05-10', :end_time => '2010-05-11').body
       end
     end
   end
