@@ -7,9 +7,9 @@ Shindo.tests('Fog::Compute[:vsphere] | vm_migrate request', ['vsphere']) do
   tests('The response should') do
     response = compute.vm_migrate('instance_uuid' => powered_on_vm)
     test('be a kind of Hash') { response.kind_of? Hash }
-    test('should have a task_state key') { response.has_key? 'task_state' }
+    test('should have a task_state key') { response.key? 'task_state' }
   end
-  
+
   tests('The expected options') do
     raises(ArgumentError, 'raises ArgumentError when instance_uuid option is missing') { compute.vm_migrate }
   end
