@@ -8,7 +8,7 @@ Shindo.tests('Fog::Compute[:vsphere] | vm_reconfig_memory request', ['vsphere'])
   tests('The response should') do
     response = compute.vm_reconfig_memory('instance_uuid' => reconfig_target, 'memory' => reconfig_spec)
     test('be a kind of Hash') { response.kind_of? Hash }
-    test('should have a task_state key') { response.has_key? 'task_state' }
+    test('should have a task_state key') { response.key? 'task_state' }
   end
 
   tests('The expected options') do
