@@ -5,7 +5,7 @@ Shindo.tests('Fog::Compute[:xenserver] | HostMetrics model', ['xenserver']) do
   tests('The HostMetrics model should') do
     tests('have attributes') do
       model_attribute_hash = host.metrics.attributes
-      attributes = [ 
+      attributes = [
         :reference,
         :uuid,
         :memory_free,
@@ -20,7 +20,7 @@ Shindo.tests('Fog::Compute[:xenserver] | HostMetrics model', ['xenserver']) do
       end
       tests("The attributes hash should have key") do
         attributes.each do |attribute|
-          test("#{attribute}") { model_attribute_hash.has_key? attribute }
+          test("#{attribute}") { model_attribute_hash.key? attribute }
         end
       end
     end
@@ -30,17 +30,17 @@ Shindo.tests('Fog::Compute[:xenserver] | HostMetrics model', ['xenserver']) do
     end
 
     test("have a last_updated Time property") { host.metrics.last_updated.kind_of? Time }
-    
-    test("return a valid memory_free ammount") do 
-      (host.metrics.memory_free =~ /^\d+$/) == 0 
+
+    test("return a valid memory_free ammount") do
+      (host.metrics.memory_free =~ /^\d+$/) == 0
     end
 
     test("have memory_free > 0") { host.metrics.memory_free.to_i > 0 }
-    
+
     test("return a valid memory_total ammount") do
-      (host.metrics.memory_total =~ /^\d+$/) == 0 
+      (host.metrics.memory_total =~ /^\d+$/) == 0
     end
-    
+
     test("have memory_total > 0") { host.metrics.memory_total.to_i > 0 }
 
   end
